@@ -67,10 +67,7 @@ char sc_sa_restart[MAX_SGR_LEN] = C_LIGHT_RED;
 char sc_sa_comment[MAX_SGR_LEN] = C_LIGHT_YELLOW;
 char sc_normal[MAX_SGR_LEN] = C_NORMAL;
 
-/*
- * Type of persistent device names in lowercase letters
- * (e.g. "uuid", "label", "path"...) Used in sar and iostat.
- */
+/* Type of persistent device names used in sar and iostat */
 char persistent_name_type[MAX_FILE_LEN];
 
 /*
@@ -436,6 +433,37 @@ int check_dir(char *dirname)
 
 
 #ifndef SOURCE_SADC
+/*
+ ***************************************************************************
+ * Count number of comma-separated values in arguments list. For example,
+ * the number will be 3 for the list "foobar -p 1 -p 2,3,4 2 5".
+ *
+ * IN:
+ * @arg_c	Number of arguments in the list.
+ * @arg_v	Arguments list.
+ *
+ * RETURNS:
+ * Number of comma-separated values in the list.
+ ***************************************************************************
+ */
+int count_csvalues(int arg_c, char **arg_v)
+{
+	int opt = 1;
+	int nr = 0;
+	char *t;
+
+	while (opt < arg_c) {
+		if (strchr(arg_v[opt], ',')) {
+			for (t = arg_v[opt]; t; t = strchr(t + 1, ',')) {
+				nr++;
+			}
+		}
+		opt++;
+	}
+
+	return nr;
+}
+
 /*
  ***************************************************************************
  * Read /proc/devices file and get device-mapper major number.
