@@ -32,7 +32,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/utsname.h>
-#include <libgen.h>
 
 #include "version.h"
 #include "iostat.h"
@@ -125,44 +124,6 @@ void set_disk_output_unit(void)
 	}
 }
 
-/*
- ***************************************************************************
- * Get device mapper name (e.g. "dm-0") from its registered name (e.g.
- * "virtualhd-home").
- *
- * IN:
- * @name	Registered name of the device (e.g. "virtualhd-home").
- *
- * RETURNS:
- * Name of the device mapper name (e.g. "dm-0").
- ***************************************************************************
- */
-char *get_dm_name_from_registered_name(char *registered_name)
-{
-	int n;
-	char filen[PATH_MAX];
-	char target[PATH_MAX];
-
-	/*
-	 * The registered device name is a symlink pointing at its device mapper name
-	 * in the /dev/mapper directory.
-	 */
-	n = snprintf(filen, sizeof(filen), "%s/%s", DEVMAP_DIR, registered_name);
-	if ((n >= sizeof(filen)) || access(filen, F_OK)) {
-		return (NULL);
-	}
-
-	/* Read symlink */
-	n = readlink(filen, target, PATH_MAX);
-	if ((n <= 0) || (n >= PATH_MAX))
-		return (NULL);
-
-	target[n] = '\0';
-
-	/* ... and get device mapper name it points at */
-	return basename(target);
-}
-
 /*
  ***************************************************************************
  * SIGALRM signal handler. No need to reset the handler here.
@@ -224,47 +185,6 @@ void set_devices_nonexistent(struct io_device *dlist)
 	}
 }
 
-/*
- ***************************************************************************
- * Get device major and minor numbers.
- *
- * IN:
- * @filename	Name of the device ("sda", "/dev/sdb1"...)
- *
- * OUT:
- * @major	Major number of the device.
- * @minor	Minor number of the device.
- *
- * RETURNS:
- * 0 on success, and -1 otherwise.
- ***************************************************************************
- */
-int get_major_minor_nr(char filename[], int *major, int *minor)
-{
-	struct stat statbuf;
-	char *bang;
-	char dfile[MAX_PF_NAME];
-
-	snprintf(dfile, sizeof(dfile), "%s%s", filename[0] == '/' ? "" : SLASH_DEV, filename);
-	dfile[sizeof(dfile) - 1] = '\0';
-
-	while ((bang = strchr(dfile, '!'))) {
-		/*
-		 * Some devices may have had a slash replaced with a bang character (eg. cciss!c0d0...)
-		 * Restore their original names so that they can be found in /dev directory.
-		 */
-		*bang = '/';
-	}
-
-	if (__stat(dfile, &statbuf) < 0)
-		return -1;
-
-	*major = __major(statbuf.st_rdev);
-	*minor = __minor(statbuf.st_rdev);
-
-	return 0;
-}
-
 /*
  ***************************************************************************
  * Check if a device is present in the list, and add it if requested.
@@ -276,10 +196,6 @@ int get_major_minor_nr(char filename[], int *major, int *minor)
  * @dtype	T_PART_DEV (=2) if the device and all its partitions should
  *		also be read (option -p used), T_GROUP (=3) if it's a group
  *		name, and 0 otherwise.
- * @major	Major number of the device (set to UKWN_MAJ_NR by caller if
- *		unknown: In this case, major and minor numbers will be
- *		determined here).
- * @minor	Minor number of the device.
  *
  * RETURNS:
  * Pointer on the io_device structure in the list where the device is located
@@ -288,12 +204,10 @@ int get_major_minor_nr(char filename[], int *major, int *minor)
  * don't want to add it.
  ***************************************************************************
  */
-struct io_device *add_list_device(struct io_device **dlist, char *name, int dtype,
-				  int major, int minor)
+struct io_device *add_list_device(struct io_device **dlist, char *name, int dtype)
 {
 	struct io_device *d, *ds;
-	int i, rc = 0, maj_nr, min_nr;
-	char *dm_name;
+	int i, rc = 0;
 
 	if (strnlen(name, MAX_NAME_LEN) == MAX_NAME_LEN)
 		/* Device name is too long */
@@ -339,23 +253,7 @@ struct io_device *add_list_device(struct io_device **dlist, char *name, int dtyp
 		}
 		memset(d->dev_stats[i], 0, sizeof(struct io_stats));
 	}
-	if (DISPLAY_DEVMAP_NAME(flags)) {
-		/*
-		 * Save device mapper name (e.g. "dm-0") instead of
-		 * its registered name (e.g. "virtualhd-home")
-		 * This is because we won't read stats for a file named "virtualhd-home" but
-		 * for a file named "dm-0" (we will display "virtualhd-home" anyway at the end
-		 * because option -N has been used).
-		 */
-		dm_name = get_dm_name_from_registered_name(name);
-		if (!dm_name) {
-			dm_name = name;
-		}
-		strncpy(d->name, dm_name, sizeof(d->name) - 1);
-	}
-	else {
-		strncpy(d->name, name, sizeof(d->name));
-	}
+	strncpy(d->name, name, MAX_NAME_LEN);
 	d->name[MAX_NAME_LEN - 1] = '\0';
 	d->exist = TRUE;
 	d->next = ds;
@@ -379,24 +277,52 @@ struct io_device *add_list_device(struct io_device **dlist, char *name, int dtyp
 			/* This is a partition (T_PART) */
 			d->dev_tp = T_PART;
 		}
-
-		/* Save major and minor numbers */
-		if (major != UKWN_MAJ_NR) {
-			d->major = major;
-			d->minor = minor;
-		}
-		else {
-			/* Look for device major and minor numbers */
-			if (get_major_minor_nr(d->name, &maj_nr, &min_nr) == 0) {
-				d->major = maj_nr;
-				d->minor = min_nr;
-			}
-		}
 	}
 
 	return d;
 }
 
+/*
+ ***************************************************************************
+ * Get device major and minor numbers.
+ *
+ * IN:
+ * @filename	Name of the device ("sda", "/dev/sdb1"...)
+ *
+ * OUT:
+ * @major	Major number of the device.
+ * @minor	Minor number of the device.
+ *
+ * RETURNS:
+ * 0 on success, and -1 otherwise.
+ ***************************************************************************
+ */
+int get_major_minor_nr(char filename[], int *major, int *minor)
+{
+	struct stat statbuf;
+	char *bang;
+	char dfile[MAX_PF_NAME];
+
+	snprintf(dfile, sizeof(dfile), "%s%s", filename[0] == '/' ? "" : SLASH_DEV, filename);
+	dfile[sizeof(dfile) - 1] = '\0';
+
+	while ((bang = strchr(dfile, '!'))) {
+		/*
+		 * Some devices may have had a slash replaced with a bang character (eg. cciss!c0d0...)
+		 * Restore their original names so that they can be found in /dev directory.
+		 */
+		*bang = '/';
+	}
+
+	if (__stat(dfile, &statbuf) < 0)
+		return -1;
+
+	*major = __major(statbuf.st_rdev);
+	*minor = __minor(statbuf.st_rdev);
+
+	return 0;
+}
+
 /*
  ***************************************************************************
  * Read sysfs stat for current block device or partition.
@@ -540,6 +466,7 @@ int read_sysfs_device_part_stat_work(int curr, char *dname, char *sysdev)
 	struct io_stats sdev;
 	struct io_device *d;
 	char dfile[MAX_PF_NAME], filename[MAX_PF_NAME + 512];
+	int major, minor;
 
 	snprintf(dfile, sizeof(dfile), "%s/%s/%s", sysdev, __BLOCK, dname);
 	dfile[sizeof(dfile) - 1] = '\0';
@@ -560,9 +487,17 @@ int read_sysfs_device_part_stat_work(int curr, char *dname, char *sysdev)
 		if (read_sysfs_file_stat_work(filename, &sdev) < 0)
 			continue;
 
-		d = add_list_device(&dev_list, drd->d_name, 0, UKWN_MAJ_NR, 0);
+		d = add_list_device(&dev_list, drd->d_name, 0);
 		if (d != NULL) {
 			*(d->dev_stats[curr]) = sdev;
+
+			if (!d->major) {
+				/* Get major and minor numbers for given device */
+				if (get_major_minor_nr(d->name, &major, &minor) == 0) {
+					d->major = major;
+					d->minor = minor;
+				}
+			}
 		}
 	}
 
@@ -622,6 +557,7 @@ int read_sysfs_all_devices_stat_work(int curr, char *sysblock)
 	struct io_stats sdev;
 	struct io_device *d;
 	char dfile[MAX_PF_NAME];
+	int major, minor;
 
 	/* Open __sys/block directory */
 	if ((dir = __opendir(sysblock)) == NULL)
@@ -639,9 +575,17 @@ int read_sysfs_all_devices_stat_work(int curr, char *sysblock)
 		if (read_sysfs_file_stat_work(dfile, &sdev) < 0)
 			continue;
 
-		d = add_list_device(&dev_list, drd->d_name, 0, UKWN_MAJ_NR, 0);
+		d = add_list_device(&dev_list, drd->d_name, 0);
 		if (d != NULL) {
 			*(d->dev_stats[curr]) = sdev;
+
+			if (!d->major) {
+				/* Get major and minor numbers for given device */
+				if (get_major_minor_nr(d->name, &major, &minor) == 0) {
+					d->major = major;
+					d->minor = minor;
+				}
+			}
 		}
 	}
 
@@ -699,6 +643,15 @@ int read_sysfs_all_devices_stat(int curr)
 int read_sysfs_part_stat_work(int curr, struct io_device *d, char *sysdev)
 {
 	char dfile[MAX_PF_NAME];
+	int major, minor;
+
+	if (!d->major) {
+		/* Get major and minor numbers for given device */
+		if (get_major_minor_nr(d->name, &major, &minor) < 0)
+			return -1;
+		d->major = major;
+		d->minor = minor;
+	}
 
 	/* Read stats for device */
 	snprintf(dfile, sizeof(dfile), "%s/%s/%d:%d/%s",
@@ -864,9 +817,11 @@ void read_diskstats_stat_work(int curr, char *diskstats)
 			/* Unknown entry: Ignore it */
 			continue;
 
-		d = add_list_device(&dev_list, dev_name, 0, major, minor);
+		d = add_list_device(&dev_list, dev_name, 0);
 		if (d != NULL) {
 			*d->dev_stats[curr] = sdev;
+			d->major = major;
+			d->minor = minor;
 		}
 	}
 	fclose(fp);
@@ -2091,7 +2046,7 @@ int main(int argc, char **argv)
 							}
 						}
 						/* Store device name */
-						add_list_device(&dev_list, devname, T_PART_DEV, 0, 0);
+						add_list_device(&dev_list, devname, T_PART_DEV);
 					}
 				}
 				opt++;
@@ -2112,7 +2067,7 @@ int main(int argc, char **argv)
 			 * and one for the trailing '\0'.
 			 */
 			snprintf(group_name, MAX_NAME_LEN, " %-.*s", MAX_NAME_LEN - 2, argv[opt++]);
-			add_list_device(&dev_list, group_name, T_GROUP, 0, 0);
+			add_list_device(&dev_list, group_name, T_GROUP);
 		}
 
 		else if (!strcmp(argv[opt], "--human")) {
@@ -2301,7 +2256,7 @@ int main(int argc, char **argv)
 						devname = persist_devname;
 					}
 				}
-				add_list_device(&dev_list, devname, 0, UKWN_MAJ_NR, 0);
+				add_list_device(&dev_list, devname, 0);
 			}
 			else {
 				flags |= I_D_ALL_DEVICES;
