@@ -1,5 +1,5 @@
 /*
- * json_stats.c: Functions used by sadf to display statistics in JSON format.
+ * json_stats.c: Funtions used by sadf to display statistics in JSON format.
  * (C) 1999-2020 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
@@ -2207,16 +2207,19 @@ __print_funct_t json_print_filesystem_stats(struct activity *a, int curr, int ta
 	int i;
 	struct stats_filesystem *sfc;
 	int sep = FALSE;
+	char *dev_name;
 
 	xprintf(tab++, "\"filesystems\": [");
 
 	for (i = 0; i < a->nr[curr]; i++) {
 		sfc = (struct stats_filesystem *) ((char *) a->buf[curr] + i * a->msize);
 
+		/* Get name to display (persistent or standard fs name, or mount point) */
+		dev_name = get_fs_name_to_display(a, flags, sfc);
+
 		if (a->item_list != NULL) {
 			/* A list of devices has been entered on the command line */
-			if (!search_list_item(a->item_list,
-					      DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name))
+			if (!search_list_item(a->item_list, dev_name))
 				/* Device not found */
 				continue;
 		}
@@ -2235,7 +2238,7 @@ __print_funct_t json_print_filesystem_stats(struct activity *a, int curr, int ta
 			 "\"Iused\": %llu, "
 			 "\"%%Iused\": %.2f}",
 			 DISPLAY_MOUNT(a->opt_flags) ? "mountpoint" : "filesystem",
-			 DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name,
+			 dev_name,
 			 (double) sfc->f_bfree / 1024 / 1024,
 			 (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024,
 			 sfc->f_blocks ? SP_VALUE(sfc->f_bfree, sfc->f_blocks, sfc->f_blocks)
