@@ -1,5 +1,5 @@
 /*
- * pcp_stats.c: Functions used by sadf to create PCP archive files.
+ * pcp_stats.c: Funtions used by sadf to create PCP archive files.
  * (C) 2019-2020 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
@@ -2042,56 +2042,51 @@ __print_funct_t pcp_print_filesystem_stats(struct activity *a, int curr, unsigne
 	int i;
 	struct stats_filesystem *sfc;
 	char buf[64];
+	char *dev_name;
 
 	for (i = 0; i < a->nr[curr]; i++) {
-
 		sfc = (struct stats_filesystem *) ((char *) a->buf[curr] + i * a->msize);
 
+		/* Get name to display (persistent or standard fs name, or mount point) */
+		dev_name = get_fs_name_to_display(a, flags, sfc);
+
 		if (a->item_list != NULL) {
 			/* A list of devices has been entered on the command line */
-			if (!search_list_item(a->item_list,
-					      DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name))
+			if (!search_list_item(a->item_list, dev_name))
 				/* Device not found */
 				continue;
 		}
 
 		snprintf(buf, sizeof(buf), "%.0f",
 			 (double) sfc->f_bfree / 1024 / 1024);
-		pmiPutValue("fs.util.fsfree",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.fsfree", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%.0f",
 			 (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024);
-		pmiPutValue("fs.util.fsused",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.fsused", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%f",
 			 sfc->f_blocks ? SP_VALUE(sfc->f_bfree, sfc->f_blocks, sfc->f_blocks)
 				       : 0.0);
-		pmiPutValue("fs.util.fsused_pct",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.fsused_pct", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%f",
 			 sfc->f_blocks ? SP_VALUE(sfc->f_bavail, sfc->f_blocks, sfc->f_blocks)
 				       : 0.0);
-		pmiPutValue("fs.util.ufsused_pct",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.ufsused_pct", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%llu",
 			 sfc->f_ffree);
-		pmiPutValue("fs.util.ifree",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.ifree", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%llu",
 			 sfc->f_files - sfc->f_ffree);
-		pmiPutValue("fs.util.iused",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.iused", dev_name, buf);
 
 		snprintf(buf, sizeof(buf), "%f",
 			 sfc->f_files ? SP_VALUE(sfc->f_ffree, sfc->f_files, sfc->f_files)
 				      : 0.0);
-		pmiPutValue("fs.util.iused_pct",
-			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+		pmiPutValue("fs.util.iused_pct", dev_name, buf);
 	}
 #endif	/* HAVE_PCP */
 }
