@@ -1,6 +1,6 @@
 /*
  * pcp_stats.h: Include file used to display system statistics in PCP format.
- * (C) 2019 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 2019-2020 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _PCP_STATS_H
@@ -89,5 +89,11 @@ __print_funct_t pcp_print_fchost_stats
 	(struct activity *, int, unsigned long long, struct record_header *);
 __print_funct_t pcp_print_softnet_stats
 	(struct activity *, int, unsigned long long, struct record_header *);
+__print_funct_t pcp_print_psicpu_stats
+	(struct activity *, int, unsigned long long, struct record_header *);
+__print_funct_t pcp_print_psiio_stats
+	(struct activity *, int, unsigned long long, struct record_header *);
+__print_funct_t pcp_print_psimem_stats
+	(struct activity *, int, unsigned long long, struct record_header *);
 
 #endif /* _PCP_STATS_H */
