@@ -612,6 +612,11 @@ struct file_header {
  * Base magical number for activities.
  */
 #define ACTIVITY_MAGIC_BASE	0x8a
+/*
+ * Magical value used for activities with
+ * unknown format (used for sadf -H only).
+ */
+#define ACTIVITY_MAGIC_UNKNOWN	0x89
 
 /* List of activities saved in file */
 struct file_activity {
@@ -654,8 +659,6 @@ struct file_activity {
 #define FILE_ACTIVITY_UL_NR	0	/* Nr of unsigned long in file_activity structure */
 #define FILE_ACTIVITY_U_NR	9	/* Nr of [unsigned] int in file_activity structure */
 
-#define MAX_ITEM_STRUCT_SIZE	1024	/* Used for sanity check */
-
 /*
  * Description of an extra structure.
  * The composition of this structure should not change in time.
@@ -739,7 +742,7 @@ struct record_header {
 	 */
 	unsigned char record_type;
 	/*
-	 * Timestamp: Hour (0-23), minute (0-59) and second (0-60).
+	 * Timestamp: Hour (0-23), minute (0-59) and second (0-59).
 	 * Used to determine TRUE time.
 	 * Hour value depends in fact on timezone (TZ variable) value.
 	 */
@@ -1500,6 +1503,8 @@ char *get_sa_devname
 	(unsigned int, unsigned int, unsigned long long [], unsigned int, uint64_t);
 void get_file_timestamp_struct
 	(uint64_t, struct tm *, struct file_header *);
+char *get_fs_name_to_display
+	(struct activity *, uint64_t, struct stats_filesystem *);
 unsigned long long get_global_cpu_statistics
 	(struct activity *, int, int, uint64_t, unsigned char []);
 void get_global_soft_statistics
