@@ -1496,17 +1496,6 @@ int read_record_hdr(int ifd, void *buffer, struct record_header *record_hdr,
 			       record_hdr->hour, record_hdr->minute, record_hdr->second);
 		}
 
-		/* Sanity checks */
-		if ((record_hdr->record_type <= 0) || (record_hdr->record_type > R_EXTRA_MAX) ||
-		    (record_hdr->hour > 23) || (record_hdr->minute > 59) || (record_hdr->second > 60)) {
-#ifdef DEBUG
-			fprintf(stderr, "%s: record_type=%d HH:MM:SS=%02d:%02d:%02d\n",
-				__FUNCTION__, record_hdr->record_type,
-				record_hdr->hour, record_hdr->minute, record_hdr->second);
-#endif
-			return 2;
-		}
-
 		/*
 		 * Skip unknown extra structures if present.
 		 * This will be done later for R_COMMENT and R_RESTART records, as extra structures
@@ -1548,7 +1537,7 @@ void copy_structures(struct activity *act[], unsigned int id_seq[],
 		p = get_activity_position(act, id_seq[i], EXIT_IF_NOT_FOUND);
 
 		memcpy(act[p]->buf[dest], act[p]->buf[src],
-		       (size_t) act[p]->msize * (size_t) act[p]->nr_allocated * (size_t) act[p]->nr2);
+		       (size_t) act[p]->msize * (size_t) act[p]->nr[src] * (size_t) act[p]->nr2);
 		act[p]->nr[dest] = act[p]->nr[src];
 	}
 }
@@ -1988,8 +1977,7 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 
 		/*
 		 * Every activity, known or unknown, should have
-		 * at least one item and sub-item, and a size value in
-		 * a defined range.
+		 * at least one item and sub-item, and a positive size value.
 		 * Also check that the number of items and sub-items
 		 * doesn't exceed a max value. This is necessary
 		 * because we will use @nr and @nr2 to
@@ -2000,10 +1988,10 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 		 */
 		if ((fal->nr < 1) || (fal->nr2 < 1) ||
 		    (fal->nr > NR_MAX) || (fal->nr2 > NR2_MAX) ||
-		    (fal->size <= 0) || (fal->size > MAX_ITEM_STRUCT_SIZE)) {
+		    (fal->size <= 0)) {
 #ifdef DEBUG
-			fprintf(stderr, "%s: id=%d nr=%d nr2=%d size=%d\n",
-				__FUNCTION__, fal->id, fal->nr, fal->nr2, fal->size);
+			fprintf(stderr, "%s: id=%d nr=%d nr2=%d\n",
+				__FUNCTION__, fal->id, fal->nr, fal->nr2);
 #endif
 			goto format_error;
 		}
@@ -2012,11 +2000,19 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 			/* Unknown activity */
 			continue;
 
-		if ((fal->magic != act[p]->magic) && !DISPLAY_HDR_ONLY(flags)) {
-			skip = TRUE;
-		}
-		else {
-			skip = FALSE;
+		skip = FALSE;
+		if (fal->magic != act[p]->magic) {
+			/* Bad magical number */
+			if (DISPLAY_HDR_ONLY(flags)) {
+				/*
+				 * This is how sadf -H knows that this
+				 * activity has an unknown format.
+				 */
+				act[p]->magic = ACTIVITY_MAGIC_UNKNOWN;
+			}
+			else {
+				skip = TRUE;
+			}
 		}
 
 		/* Check max value for known activities */
@@ -2031,8 +2027,7 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 		/*
 		 * Number of fields of each type ("long long", or "long"
 		 * or "int") composing the structure with statistics may
-		 * only increase with new sysstat versions, unless we change
-		 * the activity's magic number. Here, we may
+		 * only increase with new sysstat versions. Here, we may
 		 * be reading a file created by current sysstat version,
 		 * or by an older or a newer version.
 		 */
@@ -2043,7 +2038,15 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 		     ((fal->types_nr[0] <= act[p]->gtypes_nr[0]) &&
 		     (fal->types_nr[1] <= act[p]->gtypes_nr[1]) &&
 		     (fal->types_nr[2] <= act[p]->gtypes_nr[2]))) &&
-		     (fal->magic == act[p]->magic) && !DISPLAY_HDR_ONLY(flags)) {
+		     (act[p]->magic != ACTIVITY_MAGIC_UNKNOWN) && !DISPLAY_HDR_ONLY(flags)) {
+			/*
+			 * This may not be an error (that's actually why we may have changed
+			 * the magic number for this activity above).
+			 * So, if the activity magic number has changed (e.g.: ACTIVITY_MAGIC_UNKNOWN)
+			 * and we want to display only the header, then ignore the error.
+			 * If we want to also display the stats then we must stop here because
+			 * we won't know how to map the contents of the stats structure.
+			 */
 #ifdef DEBUG
 			fprintf(stderr, "%s: id=%d file=%d,%d,%d activity=%d,%d,%d\n",
 				__FUNCTION__, fal->id, fal->types_nr[0], fal->types_nr[1], fal->types_nr[2],
@@ -2060,6 +2063,13 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 			goto format_error;
 		}
 
+		if (skip)
+			/*
+			 * This is an unknown activity and we want stats about it:
+			 * This is not possible so skip it.
+			 */
+			continue;
+
 		for (k = 0; k < 3; k++) {
 			act[p]->ftypes_nr[k] = fal->types_nr[k];
 		}
@@ -2071,15 +2081,12 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t f
 		act[p]->nr_ini = fal->nr;
 		act[p]->nr2    = fal->nr2;
 		act[p]->fsize  = fal->size;
-
 		/*
 		 * This is a known activity with a known format
 		 * (magical number). Only such activities will be displayed.
 		 * (Well, this may also be an unknown format if we have entered sadf -H.)
 		 */
-		if (!skip) {
-			id_seq[j++] = fal->id;
-		}
+		id_seq[j++] = fal->id;
 	}
 
 	while (j < NR_ACT) {
@@ -2650,6 +2657,39 @@ void set_bitmaps(struct activity *act[], uint64_t *flags)
 	}
 }
 
+/*
+ ***************************************************************************
+ * Count number of comma-separated values in arguments list. For example,
+ * the number will be 3 for "sar --dev=sda,sdb,sdc -dp 2 5", 1 for
+ * "sar --dev=sda -dp 2 5" and 0 for "sar --dev= -dp 2 5".
+ *
+ * IN:
+ * @arg_v	Argument containing the list of coma-separated values.
+ *
+ * RETURNS:
+ * Number of comma-separated values in the list.
+ ***************************************************************************
+ */
+int count_csval_arg(char *arg_v)
+{
+	int nr = 0;
+	char *t;
+
+	if (arg_v[0] == '\0')
+		return 0;
+
+	if (strchr(arg_v, ',')) {
+		for (t = arg_v; t; t = strchr(t + 1, ',')) {
+			nr++;
+		}
+	}
+	if (!nr) {
+		nr = 1;
+	}
+
+	return nr;
+}
+
 /*
  ***************************************************************************
  * Look for item in list.
@@ -2998,7 +3038,7 @@ int print_special_record(struct record_header *record_hdr, uint64_t l_flags,
 		 * not been collected in file (or if it has an unknown format).
 		 */
 		for (p = 0; p < NR_ACT; p++) {
-			if (HAS_PERSISTENT_VALUES(act[p]->options) && (act[p]->nr_ini > 0)) {
+			if (HAS_PERSISTENT_VALUES(act[p]->options)) {
 				act[p]->nr_ini = file_hdr->sa_cpu_nr;
 				if (act[p]->nr_ini > act[p]->nr_allocated) {
 					reallocate_all_buffers(act[p], act[p]->nr_ini);
@@ -3268,4 +3308,38 @@ void get_global_soft_statistics(struct activity *a, int prev, int curr,
 		ssnp_all->flow_limit += ssnp->flow_limit;
 	}
 }
+
+/*
+ ***************************************************************************
+ * Get filesystem name to display. This may be either the persistent name
+ * if requested by the user, the standard filesystem name (e.g. /dev/sda1,
+ * /dev/sdb3, etc.) or the mount point. This is used when displaying
+ * filesystem statistics: sar -F or sadf -- -F).
+ *
+ * IN:
+ * @a		Activity structure.
+ * @flags	Flags for common options and system state.
+ * @st_fs	Statistics for current filesystem.
+ *
+ * RETURNS:
+ * Filesystem name to display.
+ ***************************************************************************
+ */
+char *get_fs_name_to_display(struct activity *a, uint64_t flags, struct stats_filesystem *st_fs)
+{
+	char *pname = NULL, *persist_dev_name;
+	char fname[MAX_FS_LEN];
+
+	if (DISPLAY_PERSIST_NAME_S(flags) && !DISPLAY_MOUNT(a->opt_flags)) {
+		strncpy(fname, st_fs->fs_name, sizeof(fname));
+		fname[sizeof(fname) - 1] = '\0';
+		if ((persist_dev_name = get_persistent_name_from_pretty(basename(fname))) != NULL) {
+			pname = persist_dev_name;
+		}
+	}
+	if (!pname) {
+		pname = DISPLAY_MOUNT(a->opt_flags) ? st_fs->mountp : st_fs->fs_name;
+	}
+	return pname;
+}
 #endif /* SOURCE_SADC undefined */
