@@ -1,5 +1,5 @@
 /*
- * sadf_misc.c: Functions used by sadf to display special records
+ * sadf_misc.c: Funtions used by sadf to display special records
  * (C) 2011-2020 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
@@ -1276,7 +1276,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile,
 				printf("x%d", fal->nr2);
 			}
 			printf("\t(%d,%d,%d)", fal->types_nr[0], fal->types_nr[1], fal->types_nr[2]);
-			if ((p >= 0) && (act[p]->magic != fal->magic)) {
+			if ((p >= 0) && (act[p]->magic == ACTIVITY_MAGIC_UNKNOWN)) {
 				printf(_(" \t[Unknown format]"));
 			}
 			printf("\n");
@@ -1539,7 +1539,7 @@ __nr_t count_new_filesystem(struct activity *a, int curr)
 		sfc = (struct stats_filesystem *) ((char *) a->buf[curr] + i * a->msize);
 
 		nr += add_list_item(&(a->item_list),
-				    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name,
+				    get_fs_name_to_display(a, flags, sfc),
 				    MAX_FS_LEN);
 	}
 
