@@ -1,6 +1,6 @@
 /*
  * xml_stats.h: Include file used to display system statistics in XML.
- * (C) 1999-2019 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2020 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _XML_STATS_H
@@ -93,5 +93,11 @@ __print_funct_t xml_print_fchost_stats
 	(struct activity *, int, int, unsigned long long);
 __print_funct_t xml_print_softnet_stats
 	(struct activity *, int, int, unsigned long long);
+__print_funct_t xml_print_psicpu_stats
+	(struct activity *, int, int, unsigned long long);
+__print_funct_t xml_print_psiio_stats
+	(struct activity *, int, int, unsigned long long);
+__print_funct_t xml_print_psimem_stats
+	(struct activity *, int, int, unsigned long long);
 
 #endif /* _XML_STATS_H */
